@@ -63,7 +63,7 @@ import csv
 
 
 class info():
-    version = '1.0'
+    version = '1.1'
     description = 'CSV file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -123,7 +123,8 @@ def parse(data, raw=False, quiet=False):
     # Clear any blank lines
     cleandata = list(filter(None, cleandata))
 
-    if cleandata:
+    if jc.utils.has_data(data):
+
         dialect = None
         try:
             dialect = csv.Sniffer().sniff(data[:1024])
