@@ -60,7 +60,7 @@ import jc.utils
 
 
 class info():
-    version = '1.0'
+    version = '1.1'
     description = '/etc/gshadow file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -131,7 +131,8 @@ def parse(data, raw=False, quiet=False):
     # Clear any blank lines
     cleandata = list(filter(None, cleandata))
 
-    if cleandata:
+    if jc.utils.has_data(data):
+
         for entry in cleandata:
             if entry.startswith('#'):
                 continue
