@@ -97,7 +97,7 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.1'
+    version = '1.2'
     description = 'lsof command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -169,12 +169,11 @@ def parse(data, raw=False, quiet=False):
 
     raw_output = []
 
-    linedata = data.splitlines()
-
     # Clear any blank lines
-    cleandata = list(filter(None, linedata))
+    cleandata = list(filter(None, data.splitlines()))
+
+    if jc.utils.has_data(data):
 
-    if cleandata:
         cleandata[0] = cleandata[0].lower()
         cleandata[0] = cleandata[0].replace('/', '_')
 
