@@ -32,7 +32,7 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.1'
+    version = '1.3'
     description = 'pip list command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -88,28 +88,28 @@ def parse(data, raw=False, quiet=False):
 
     raw_output = []
 
-    linedata = data.splitlines()
-
     # Clear any blank lines
-    cleandata = list(filter(None, linedata))
+    cleandata = list(filter(None, data.splitlines()))
 
-    # detect legacy output type
-    if ' (' in cleandata[0]:
-        for row in cleandata:
-            raw_output.append({'package': row.split(' (')[0],
-                               'version': row.split(' (')[1].rstrip(')')})
+    if jc.utils.has_data(data):
 
-    # otherwise normal table output
-    else:
-        # clear separator line
-        for i, line in reversed(list(enumerate(cleandata))):
-            if '---' in line:
-                cleandata.pop(i)
+        # detect legacy output type
+        if ' (' in cleandata[0]:
+            for row in cleandata:
+                raw_output.append({'package': row.split(' (')[0],
+                                   'version': row.split(' (')[1].rstrip(')')})
 
-        cleandata[0] = cleandata[0].lower()
+        # otherwise normal table output
+        else:
+            # clear separator line
+            for i, line in reversed(list(enumerate(cleandata))):
+                if '---' in line:
+                    cleandata.pop(i)
 
-        if cleandata:
-            raw_output = jc.parsers.universal.simple_table_parse(cleandata)
+            cleandata[0] = cleandata[0].lower()
+
+            if cleandata:
+                raw_output = jc.parsers.universal.simple_table_parse(cleandata)
 
     if raw:
         return raw_output
