@@ -59,7 +59,7 @@ import jc.utils
 
 
 class info():
-    version = '1.1'
+    version = '1.3'
     description = 'systemctl list-jobs command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -122,28 +122,32 @@ def parse(data, raw=False, quiet=False):
     if not quiet:
         jc.utils.compatibility(__name__, info.compatible)
 
-    linedata = data.splitlines()
     # Clear any blank lines
-    linedata = list(filter(None, linedata))
-    # clean up non-ascii characters, if any
-    cleandata = []
-    for entry in linedata:
-        cleandata.append(entry.encode('ascii', errors='ignore').decode())
-
-    header_text = cleandata[0]
-    header_text = header_text.lower()
-    header_list = header_text.split()
-
+    linedata = list(filter(None, data.splitlines()))
     raw_output = []
 
-    for entry in cleandata[1:]:
-        if 'No jobs running.' in entry or 'jobs listed.' in entry:
-            break
+    if jc.utils.has_data(data):
 
-        else:
-            entry_list = entry.split(maxsplit=4)
-            output_line = dict(zip(header_list, entry_list))
-            raw_output.append(output_line)
+        cleandata = []
+
+        # clean up non-ascii characters, if any
+        for entry in linedata:
+            cleandata.append(entry.encode('ascii', errors='ignore').decode())
+
+        header_text = cleandata[0]
+        header_text = header_text.lower()
+        header_list = header_text.split()
+
+        raw_output = []
+
+        for entry in cleandata[1:]:
+            if 'No jobs running.' in entry or 'jobs listed.' in entry:
+                break
+
+            else:
+                entry_list = entry.split(maxsplit=4)
+                output_line = dict(zip(header_list, entry_list))
+                raw_output.append(output_line)
 
     if raw:
         return raw_output
