@@ -30,7 +30,7 @@ import jc.utils
 
 
 class info():
-    version = '1.2'
+    version = '1.4'
     description = 'uname -a command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -43,6 +43,10 @@ class info():
 __version__ = info.version
 
 
+class ParseError(Exception):
+    pass
+
+
 def process(proc_data):
     """
     Final processing to conform to the schema.
@@ -88,12 +92,16 @@ def parse(data, raw=False, quiet=False):
         jc.utils.compatibility(__name__, info.compatible)
 
     raw_output = {}
-    split_line = data.split()
 
-    if len(split_line) > 1:
+    if jc.utils.has_data(data):
+
         # check for OSX output
         if data.startswith('Darwin'):
             parsed_line = data.split()
+
+            if len(parsed_line) < 5:
+                raise ParseError('Could not parse uname output. Make sure to use "uname -a".')
+
             raw_output['machine'] = parsed_line.pop(-1)
             raw_output['kernel_name'] = parsed_line.pop(0)
             raw_output['node_name'] = parsed_line.pop(0)
@@ -103,6 +111,10 @@ def parse(data, raw=False, quiet=False):
         # otherwise use linux parser
         else:
             parsed_line = data.split(maxsplit=3)
+
+            if len(parsed_line) < 3:
+                raise ParseError('Could not parse uname output. Make sure to use "uname -a".')
+
             raw_output['kernel_name'] = parsed_line.pop(0)
             raw_output['node_name'] = parsed_line.pop(0)
             raw_output['kernel_release'] = parsed_line.pop(0)
