@@ -34,7 +34,7 @@ import jc.utils
 
 
 class info():
-    version = '1.0'
+    version = '1.2'
     description = 'uptime command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -107,10 +107,10 @@ def parse(data, raw=False, quiet=False):
         jc.utils.compatibility(__name__, info.compatible)
 
     raw_output = {}
-
     cleandata = data.splitlines()
 
-    if cleandata:
+    if jc.utils.has_data(data):
+
         parsed_line = cleandata[0].split()
 
         # allow space for odd times
